==============
CRC Calculator
==============

|PyPI version|

Installation
------------

.. code:: bash

   $ pip install crc-calculator

How to use
----------

.. code:: bash

   $ crc -h
    usage: crc [-h] [-V] polynomial data

    positional arguments:
      polynomial
      data

    options:
      -h, --help     show this help message and exit
      -V, --version  show program's version number and exit

.. |PyPI version| image:: https://img.shields.io/pypi/v/crc-calculator
   :target: https://pypi.org/project/crc-calculator/
